# <img src="https://raw.githubusercontent.com/pylhc/pylhc.github.io/master/docs/assets/logos/OMC_logo.svg" height="28"> PyLHC Tools

[![Cron Testing](https://github.com/pylhc/PyLHC/workflows/Cron%20Testing/badge.svg)](https://github.com/pylhc/PyLHC/actions?query=workflow%3A%22Cron+Testing%22)
[![Code Climate coverage](https://img.shields.io/codeclimate/coverage/pylhc/PyLHC.svg?style=popout)](https://codeclimate.com/github/pylhc/PyLHC)
[![Code Climate maintainability (percentage)](https://img.shields.io/codeclimate/maintainability-percentage/pylhc/PyLHC.svg?style=popout)](https://codeclimate.com/github/pylhc/PyLHC)
[![GitHub last commit](https://img.shields.io/github/last-commit/pylhc/PyLHC.svg?style=popout)](https://github.com/pylhc/PyLHC/)
[![GitHub release](https://img.shields.io/github/release/pylhc/PyLHC.svg?style=popout)](https://github.com/pylhc/PyLHC/)

This package is a collection of useful scripts and tools for the Optics Measurements and Corrections group (OMC) at CERN.

## Documentation

- Autogenerated docs via `Sphinx` can be found at <https://pylhc.github.io/PyLHC/>.
- General documentation of the OMC-Team is located at <https://pylhc.github.io/>

## Getting Started

This package is `Python 3.7+` compatible, and can be installed through `pip`:
```bash
pip install pylhc
```

One can also install from VCS:
```bash
git clone https://github.com/pylhc/PyLHC
pip install /path/to/PyLHC
```

Or simply from the online master branch, which is stable:
```bash
pip install git+https://github.com/pylhc/PyLHC.git#egg=pylhc
```

After installing, scripts can be run with either `python -m pylhc.SCRIPT --FLAG ARGUMENT` or by calling the `.py` files directly.

Note: some scripts access functionality only available on the CERN Technical Network.
To use those, you should make sure to install the relevant extra dependencies with `pip install path/to/Pylhc[cern]`.

## Description

This package provides tools for particle accelerator data analysis, simulations management and machine information extraction; complementing the optics measurement analysis tools of the [omc3 package](https://github.com/pylhc/omc3).

## Functionality

- `Forced DA Analysis` - Script to analyse forced DA. ([**forced_da_analysis.py**](pylhc/forced_da_analysis.py))
- `Machine Settings Info` - Prints an overview over the machine settings at a given time. ([**machine_settings_info.py**](pylhc/machine_settings_info.py))
- `BSRT Logger` and `BSRT Analysis` - Saves data coming straight from LHC BSRT FESA class and allows subsequent analysis. ([**bsrt_logger.py**](pylhc/bsrt_logger.py) & [**bsrt_analysis.py**](pylhc/bsrt_analysis.py) )
- `BPM Calibration Factors` - Compute the BPM calibration factors using ballistic optics. Two methods are available: using the beta function and using the dispersion. ([**bpm_calibration.py**](pylhc/bpm_calibration.py))

## Quality checks

- Unit and accuracy tests are run automatically through CI [Github Actions](https://github.com/pylhc/PyLHC/actions). See our workflows in this [readme](.github/workflows/README.md).
- Additional checks for code-complexity, design-rules, test-coverage and duplication are made through [CodeClimate](https://codeclimate.com/github/pylhc/PyLHC).
- Pull requests implementing functionality or fixes are merged into the master branch after passing CI, and getting a reviewer's approval.

### Changelog

See the [CHANGELOG](CHANGELOG.md) file.

### Hints for Developers

In case you want to contribute to `PyLHC`'s development, you should install it in `editable` mode:
```
git clone https://github.com/pylhc/PyLHC
pip install --editable PyLHC
```

You can install extra dependencies (as defined in `setup.py`) suited to your use case with the following commands:
```
pip install --editable PyLHC[cern]
pip install --editable PyLHC[test]
pip install --editable PyLHC[test,doc]
pip install --editable PyLHC[all]
```

Open an issue, make your changes in a branch and submit a pull request.

## Authors

* **pyLHC/OMC-Team** - *Working Group* - [pyLHC](https://github.com/orgs/pylhc/teams/omc-team)

## License

This project is licensed under the `GNU GPLv3` License - see the [LICENSE](LICENSE) file for details.
